@@ -13,6 +13,7 @@ from .base import (
     BusinessUnitAssignment,
     Generic16Mixin,
     Generic32Mixin,
+    Reference,
     Resource,
     RuleUsage,
     Value,
@@ -25,9 +26,9 @@ class AppliedDeposit(Resource):
     attr_endpoint: ClassVar[str] = "api/v2/appliedDeposits"
     attr_seq: ClassVar[str] = "applied_deposit_seq"
     applied_deposit_seq: str | None = None
-    position: str
-    payee: str
-    period: str
+    position: str | Reference
+    payee: str | Reference
+    period: str | Reference
     earning_group_id: str
     earning_code_id: str
     trial_pipeline_run: str
@@ -62,9 +63,9 @@ class Balance(Resource):
     attr_endpoint: ClassVar[str] = "api/v2/balances"
     attr_seq: ClassVar[str] = "balance_seq"
     balance_seq: str | None = None
-    position: str
-    payee: str
-    period: str
+    position: str | Reference
+    payee: str | Reference
+    period: str | Reference
     earning_group_id: str
     earning_code_id: str
     trial_pipeline_run: str
@@ -98,9 +99,8 @@ class Calendar(Resource):
     calendar_seq: str | None = None
     name: str
     description: str | None = None
-    minor_period_type: str | None = None
-    major_period_type: str | None = None
-    periods: list[str] | None = None
+    minor_period_type: str | Reference | Reference | None = None
+    major_period_type: str | Reference | Reference | None = None
     created_by: str | None = Field(None, exclude=True, repr=False)
     create_date: datetime | None = Field(None, exclude=True, repr=False)
     modified_by: str | None = Field(None, exclude=True, repr=False)
@@ -112,9 +112,9 @@ class CategoryClassifier(Resource):
     attr_endpoint: ClassVar[str] = "api/v2/categoryClassifiers"
     attr_seq: ClassVar[str] = "category_classifiers_seq"
     category_classifiers_seq: str | None = None
-    category_tree: str
-    category: str
-    classifier: str
+    category_tree: str | Reference
+    category: str | Reference
+    classifier: str | Reference
     effective_start_date: datetime
     effective_end_date: datetime
     created_by: str | None = Field(None, exclude=True, repr=False)
@@ -149,11 +149,11 @@ class Commission(Resource):
     attr_endpoint: ClassVar[str] = "api/v2/commissions"
     attr_seq: ClassVar[str] = "commission_seq"
     commission_seq: str | None = None
-    position: str
-    payee: str
-    period: str
-    incentive: str
-    credit: str
+    position: str | Reference
+    payee: str | Reference
+    period: str | Reference
+    incentive: str | Reference
+    credit: str | Reference
     pipeline_run: str
     pipeline_run_date: datetime
     value: Value
@@ -172,17 +172,17 @@ class Credit(Resource, Generic16Mixin):
     attr_seq: ClassVar[str] = "credit_seq"
     credit_seq: str | None = None
     name: str
-    position: str
-    payee: str
-    sales_order: str
-    sales_transaction: str | None = None
-    period: str
-    credit_type: str
+    position: str | Reference | Reference
+    payee: str | Reference | Reference
+    sales_order: str | Reference
+    sales_transaction: str | Reference | None = None
+    period: str | Reference | Reference
+    credit_type: str | Reference
     value: Value
     preadjusted_value: Value
     origin_type_id: str
-    reason: str | None = None
-    rule: str | None = None
+    reason: str | Reference | None = None
+    rule: str | Reference | Reference | None = None
     is_rollable: bool | None = None
     roll_date: datetime | None = None
     is_held: bool | None = None
@@ -205,15 +205,15 @@ class Deposit(Resource, Generic16Mixin):
     name: str
     earning_group_id: str
     earning_code_id: str
-    payee: str
-    position: str
-    period: str
+    payee: str | Reference
+    position: str | Reference
+    period: str | Reference
     value: Value
     preadjusted_value: Value
     origin_type_id: str
     reason: str | None = None
-    businessUnits: list[str] | None = None
-    rule: str | None = None
+    business_units: list[str] | None = None
+    rule: str | Reference | None = None
     deposit_date: datetime | None = None
     is_held: bool | None = None
     release_date: datetime | None = None
@@ -297,10 +297,10 @@ class Incentive(Resource, Generic16Mixin):
     name: str | None = None
     quota: Value | None = None
     attainment: Value | None = None
-    position: str
-    payee: str
-    period: str
-    rule: str
+    position: str | Reference
+    payee: str | Reference
+    period: str | Reference
+    rule: str | Reference
     value: Value
     release_date: datetime | None = None
     pipeline_run: str | None = None
@@ -318,10 +318,10 @@ class Measurement(Resource, Generic16Mixin):
     attr_seq: ClassVar[str] = "measurement_seq"
     measurement_seq: str | None = None
     name: str
-    position: str
-    payee: str
-    period: str
-    rule: str | None = None
+    position: str | Reference
+    payee: str | Reference
+    period: str | Reference
+    rule: str | Reference | None = None
     value: Value
     pipeline_run: str | None = None
     pipeline_run_date: datetime | None = None
@@ -355,13 +355,13 @@ class Message(Resource):
     sub_category: str
     message_log: str
     module: str
-    rule: str | None = None
-    payee: str | None = None
+    rule: str | Reference | None = None
+    payee: str | Reference | None = None
     message_type: str
-    run_period: str | None = None
+    run_period: str | Reference | None = None
     object_seq: str | None = None
     sales_transaction: str | None = None
-    position: str | None = None
+    position: str | Reference | None = None
     category: str | None = None
     credit: str | None = None
 
@@ -398,7 +398,7 @@ class Participant(Resource, Generic16Mixin):
     salary: Value | None = None
     user_id: str
     preferred_language: str | None = None
-    event_calendar: str | None = None
+    event_calendar: str | Reference | None = None
     tax_id: str | None = None
     business_units: list[str] | None = None
     created_by: str | None = Field(None, exclude=True, repr=False)
@@ -412,9 +412,9 @@ class Participant(Resource, Generic16Mixin):
 #     attr_endpoint: ClassVar[str] = "api/v2/payments"
 #     attr_seq: ClassVar[str] = "payment_seq"
 #     payment_seq: str | None = None
-#     position: str
-#     payee: str
-#     period: str
+#     position: str | Reference
+#     payee: str | Reference
+#     period: str | Reference
 #     earning_group_id: str
 #     earning_code_id: str
 #     trial_pipeline_run: str | None = None
@@ -443,9 +443,9 @@ class PaymentSummary(Resource):
     attr_endpoint: ClassVar[str] = "api/v2/paymentSummarys"
     attr_seq: ClassVar[str] = "payment_summary_seq"
     payment_summary_seq: str | None = None
-    position: str
-    participant: str
-    period: str
+    position: str | Reference
+    participant: str | Reference
+    period: str | Reference
     earning_group_id: str
     pipeline_run: str | None = None
     pipeline_run_date: datetime | None = None
@@ -468,10 +468,10 @@ class Period(Resource):
     short_name: str
     start_date: datetime
     end_date: datetime
-    period_type: str
-    calendar: str
+    period_type: str | Reference
+    calendar: str | Reference
     description: str | None = None
-    parent: str | None = None
+    parent: str | Reference | None = None
     created_by: str | None = Field(None, exclude=True, repr=False)
     create_date: datetime | None = Field(None, exclude=True, repr=False)
     modified_by: str | None = Field(None, exclude=True, repr=False)
@@ -519,7 +519,7 @@ class Pipeline(Resource):
     state: const.PipelineState
     user_id: str
     processing_unit: str = Field(repr=False)
-    period: str | None = None
+    period: str | Reference | None = None
     description: str | None = None
     status: const.PipelineStatus | None = None
     run_progress: float | None = None
@@ -580,9 +580,9 @@ class PositionRelation(Resource):
     name: str | None = None
     effective_start_date: datetime
     effective_end_date: datetime
-    parent_position: str
+    parent_position: str | Reference
     position_relation_type: str
-    child_position: str
+    child_position: str | Reference
     created_by: str | None = Field(None, exclude=True, repr=False)
     create_date: datetime | None = Field(None, exclude=True, repr=False)
     modified_by: str | None = Field(None, exclude=True, repr=False)
@@ -642,12 +642,12 @@ class Quota(Resource):
     attr_endpoint: ClassVar[str] = "api/v2/quotas"
     attr_seq: ClassVar[str] = "quota_seq"
     quota_seq: str | None = None
-    calendar: str
+    calendar: str | Reference
     name: str
     description: str | None = None
     effective_start_date: datetime
     effective_end_date: datetime
-    unit_type: str
+    unit_type: str | Reference
     model_seq: str | None = None
     business_units: list[str] | None = None
     created_by: str | None = Field(None, exclude=True, repr=False)
@@ -677,10 +677,10 @@ class SalesTransaction(Resource, Generic32Mixin):
     attr_endpoint: ClassVar[str] = "api/v2/salesTransactions"
     attr_seq: ClassVar[str] = "sales_transaction_seq"
     sales_transaction_seq: str | None = None
-    sales_order: str
+    sales_order: str | Reference
     line_number: Value
     sub_line_number: Value
-    event_type: str
+    event_type: str | Reference
     product_id: str | None = None
     product_name: str | None = None
     product_description: str | None = None
@@ -743,7 +743,7 @@ class PlanComponent(Resource):
     plan_component_seq: str | None = None
     name: str
     description: str | None = None
-    calendar: str
+    calendar: str | Reference
     effective_start_date: datetime
     effective_end_date: datetime
     business_units: list[str] | None = None
@@ -762,7 +762,7 @@ class Rule(Resource):
     rule_seq: str | None = None
     name: str
     description: str | None = None
-    calendar: str
+    calendar: str | Reference
     effective_start_date: datetime
     effective_end_date: datetime
     business_unit: list[BusinessUnitAssignment] | BusinessUnitAssignment | None = None
@@ -772,3 +772,19 @@ class Rule(Resource):
     created_by: str | None = Field(None, exclude=True, repr=False)
     create_date: datetime | None = Field(None, exclude=True, repr=False)
     modified_by: str | None = Field(None, exclude=True, repr=False)
+
+
+class CreditRule(Rule):
+    """Alias for Rule."""
+
+
+class CommissionRule(Rule):
+    """Alias for Rule."""
+
+
+class DepositRule(Rule):
+    """Alias for Rule."""
+
+
+class MeasurementRule(Rule):
+    """Alias for Rule."""
